==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/mk.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Немозната адреса",
    "No result." : "Нема резултати.",
    "Malformed JSON data." : "Лошо формирани JSON податоци.",
    "Error" : "Грешка",
    "Weather status" : "Временска прогноза",
    "Weather status in your dashboard" : "Временска прогноза во вашата контролна табла",
    "Detect location" : "Детектирај локација",
    "Set custom address" : "Поставете адреса",
    "Favorites" : "Омилени",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ведро небо во {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Облачно во {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Јасен ден во {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Јасна ноќ во {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Променливо облачно во {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Магливо во {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Слаб дожд во {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Дожд во {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Силен дожд во {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Врнежи од дожд во {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Слаби врнежи од дожд во {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Поројни врнежи од дожд во {time}",
    "More weather for {adr}" : "Повеќе информации за временската прогноза за {adr}",
    "Loading weather" : "Вчитување на времесна прогноза",
    "Set location for weather" : "Поставете локација за временска прогноза",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add as favorite" : "Додади во омилени",
    "You are not logged in." : "Не сте најавени",
    "There was an error getting the weather status information." : "Настана грешка при вчитување на инфорнации за временска прогноза.",
    "No weather information found" : "Не се пронајдени информации за временската прогноза",
    "Location not found" : "Локацијата не е пронајдена",
    "There was an error setting the location address." : "Настана грешка при поставување на адреса на локација.",
    "There was an error setting the location." : "Настана грешка при поставување на локација.",
    "There was an error saving the mode." : "Грешка при зачувување.",
    "There was an error using personal address." : "Настана грешка при користење на сопствена адреса."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/weather_status/l10n/mk.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Немозната адреса",
    "No result." : "Нема резултати.",
    "Malformed JSON data." : "Лошо формирани JSON податоци.",
    "Error" : "Грешка",
    "Weather status" : "Временска прогноза",
    "Weather status in your dashboard" : "Временска прогноза на вашата табла",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Временска прогноза интегрирана во апликацијата Табла.\nПозицијата на корисникот може автоматски да се одреди или рачно да се дефинира. Потоа се прикажува предвидување од 6 часа.\nОвој статус може да се интегрира и на други места, како што е апликацијата „Календар“.",
    "Detect location" : "Детектирај локација",
    "Set custom address" : "Поставете адреса",
    "Favorites" : "Омилени",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ведро небо во {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Облачно во {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Јасен ден во {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Јасна ноќ во {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Променливо облачно во {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Магливо во {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Слаб дожд во {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Дожд во {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Силен дожд во {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Врнежи од дожд во {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Слаби врнежи од дожд во {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Поројни врнежи од дожд во {time}",
    "More weather for {adr}" : "Повеќе информации за временската прогноза за {adr}",
    "Loading weather" : "Вчитување на временска прогноза",
    "Set location for weather" : "Поставете локација за временска прогноза",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add as favorite" : "Додади во омилени",
    "You are not logged in." : "Не сте најавени",
    "There was an error getting the weather status information." : "Настана грешка при вчитување на инфорнации за временска прогноза.",
    "No weather information found" : "Не се пронајдени информации за временската прогноза",
    "Location not found" : "Локацијата не е пронајдена",
    "There was an error setting the location address." : "Настана грешка при поставување на адреса на локација.",
    "There was an error setting the location." : "Настана грешка при поставување на локација.",
    "There was an error saving the mode." : "Грешка при зачувување.",
    "There was an error using personal address." : "Настана грешка при користење на сопствена адреса.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Временска прогноза интегрирана во апликацијата Табла.\nПозицијата на корисникот може автоматски да се одреди или рачно да се дефинира. Потоа се прикажува предвидување од 6 часа.\nОвој статус може да се интегрира и на други места, како што е апликацијата „Календар“."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
